# Components

This module contains classes that abstract various Karabo devices to make access
easier.

Component index:

- [Beam properties](beam-properties.md)
    - [XGM][extra.components.XGM]
- [Scans](scans.md)
    - [Scantool][extra.components.Scantool]
    - [Scan][extra.components.Scan]
- [Pulse patterns](pulse-patterns.md)
    - [XrayPulses][extra.components.XrayPulses]
    - [OpticalLaserPulses][extra.components.OpticalLaserPulses]
    - [PumpProbePulses][extra.components.PumpProbePulses]
    - [MachinePulses][extra.components.MachinePulses]
    - [DldPulses][extra.components.DldPulses]
- [Delay Line Detectors](delay-line-detectors.md)
    - [DelayLineDetector][extra.components.DelayLineDetector]
- [Timepix](timepix.md)
    - [Timepix3][extra.components.Timepix3]
- [Optical Lasers](optical-lasers.md)
    - [OpticalLaserDelay][extra.components.OpticalLaserDelay]
- [ADQ Digitizers](adq-digitizers.md)
    - [AdqRawChannel][extra.components.AdqRawChannel]
- [Detector motors](detector-motors.md)
    - [AGIPD1MQuadrantMotors][extra.components.AGIPD1MQuadrantMotors]
    - [JF4MHalfMotors][extra.components.JF4MHalfMotors]
